@@ -240,13 +240,18 @@ e_data_book_view_notify_update (EDataBookView *book_view,
 			     EContact    *contact)
 {
 	gboolean currently_in_view, want_in_view;
-	const char *id;
+	const char *id=NULL;
 	char *vcard;
 
 	g_mutex_lock (book_view->priv->pending_mutex);
 
 	id = e_contact_get_const (contact, E_CONTACT_UID);
-
+	if (!id) {
+		g_object_unref (contact);
+		g_mutex_unlock (book_view->priv->pending_mutex);
+		return;
+	}
+	
 	currently_in_view =
 		g_hash_table_lookup (book_view->priv->ids, id) != NULL;
 	want_in_view = e_book_backend_sexp_match_contact (
@@ -288,13 +293,19 @@ void
 e_data_book_view_notify_update_vcard (EDataBookView *book_view, char *vcard)
 {
 	gboolean currently_in_view, want_in_view;
-	const char *id;
+	const char *id = NULL;
 	EContact *contact;
 	
 	g_mutex_lock (book_view->priv->pending_mutex);
 	
 	contact = e_contact_new_from_vcard (vcard);
 	id = e_contact_get_const (contact, E_CONTACT_UID);
+	if (!id) {
+		free (vcard);
+		g_object_unref (contact);
+		g_mutex_unlock (book_view->priv->pending_mutex);
+		return;
+	}
 	
 	currently_in_view =
 		g_hash_table_lookup (book_view->priv->ids, id) != NULL;
@@ -369,7 +380,10 @@ e_data_book_view_notify_remove (EDataBookView *book_view,
 			     const char  *id)
 {
 	g_mutex_lock (book_view->priv->pending_mutex);
-	notify_remove (book_view, id);
+
+	if (g_hash_table_lookup (book_view->priv->ids, id))
+		notify_remove (book_view, id);
+	
 	g_mutex_unlock (book_view->priv->pending_mutex);
 }
 
