@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -267,7 +267,7 @@ e_cal_backend_class_init (ECalBackendClass *class)
 }
 
 /* Object initialization func for the calendar backend */
-void
+static void
 e_cal_backend_init (ECalBackend *backend)
 {
 	ECalBackendPrivate *priv;
@@ -283,7 +283,7 @@ e_cal_backend_init (ECalBackend *backend)
 	priv->queries_mutex = g_mutex_new ();
 }
 
-void
+static void
 e_cal_backend_finalize (GObject *object)
 {
 	ECalBackend *backend = (ECalBackend *)object;
@@ -297,7 +297,9 @@ e_cal_backend_finalize (GObject *object)
 
 	g_mutex_free (priv->clients_mutex);
 	g_mutex_free (priv->queries_mutex);
-
+	
+	g_free (priv->uri);
+	g_object_unref (priv->source);
 	g_free (priv);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
