@@ -5,7 +5,7 @@
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /* TODO: This could probably be made a camel object, but it isn't really required */
@@ -25,17 +25,19 @@
 #include <config.h>
 #endif
 
-#include <sys/types.h>
-#include <unistd.h>
-#include <errno.h>
-#include <string.h>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include <ctype.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include <glib.h>
 
+#include <libedataserver/e-memory.h>
+
 #include "camel-folder-thread.h"
-#include "libedataserver/e-memory.h"
 
 #define d(x) 
 #define m(x) 
@@ -107,6 +109,7 @@ prune_empty(CamelFolderThread *thread, CamelFolderThreadNode **cp)
 	lastc = (CamelFolderThreadNode *)cp;
 	while (lastc->next) {
 		c = lastc->next;
+		prune_empty(thread, &c->child);
 
 		d(printf("checking message %p %p (%08x%08x)\n", c,
 			 c->message, c->message?c->message->message_id.id.part.hi:0,
@@ -135,7 +138,6 @@ prune_empty(CamelFolderThread *thread, CamelFolderThreadNode **cp)
 				continue;
 			}
 		}
-		prune_empty(thread, &c->child);
 		lastc = c;
 	}
 }
@@ -333,7 +335,8 @@ dump_tree_rec(struct _tree_info *info, CamelFolderThreadNode *c, int depth)
 			g_hash_table_insert(info->visited, c, c);
 		}
 		if (c->message) {
-			printf("%s %p Subject: %s <%.8s>\n", p, c, camel_message_info_subject(c->message), camel_message_info_message_id(c->message)->id.hash);
+			printf("%s %p Subject: %s <%08x%08x>\n", p, c, camel_message_info_subject(c->message),
+			       camel_message_info_message_id(c->message)->id.part.hi, camel_message_info_message_id(c->message)->id.part.lo);
 			count += 1;
 		} else {
 			printf("%s %p <empty>\n", p, c);
@@ -475,7 +478,7 @@ thread_summary(CamelFolderThread *thread, GPtrArray *summary)
 		if (references) {
 			int j;
 
-			d(printf("references:\n"));
+			d(printf("%s (%s) references:\n", G_STRLOC, G_STRFUNC); )
 			for (j=0;j<references->size;j++) {
 				/* should never be empty, but just incase */
 				if (references->references[j].id.id == 0)
@@ -483,7 +486,7 @@ thread_summary(CamelFolderThread *thread, GPtrArray *summary)
 
 				c = g_hash_table_lookup(id_table, &references->references[j]);
 				if (c == NULL) {
-					d(printf("not found\n"));
+					d(printf("%s (%s) not found\n", G_STRLOC, G_STRFUNC));
 					c = e_memchunk_alloc0(thread->node_chunks);
 					g_hash_table_insert(id_table, (void *)&references->references[j], c);
 				}
@@ -512,8 +515,8 @@ thread_summary(CamelFolderThread *thread, GPtrArray *summary)
 
 #if 0
 	printf("finished\n");
-	i = camel_folder_thread_messages_dump(head);
-	printf("%d count, %d items in tree\n", uids->len, i);
+	i = camel_folder_threaded_messages_dump(head);
+	printf("%d count, %d items in tree\n", summary->len, i);
 #endif
 
 	sort_thread(&head);
