@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /* What should hopefully be a fast mail parser */
@@ -26,27 +26,23 @@
    There is almost always a reason something was done a certain way.
  */
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
-
-#include <string.h>
-
-#include <stdio.h>
 #include <errno.h>
-
-#include <regex.h>
-#include <ctype.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
 #include <glib.h>
+
+#include <libedataserver/e-memory.h>
+
+#include "camel-mime-filter.h"
 #include "camel-mime-parser.h"
 #include "camel-mime-utils.h"
-#include "camel-mime-filter.h"
-#include "camel-stream.h"
+#include "camel-private.h"
 #include "camel-seekable-stream.h"
-
-#include "libedataserver/e-memory.h"
+#include "camel-stream.h"
 
 #define r(x) 
 #define h(x) 
@@ -372,7 +368,7 @@ byte_array_to_string(GByteArray *array)
 	if (array->len == 0 || array->data[array->len-1] != '\0')
 		g_byte_array_append(array, "", 1);
 
-	return array->data;
+	return (const char *) array->data;
 }
 
 /**
@@ -1153,11 +1149,11 @@ header_append_mempool(struct _header_scan_state *s, struct _header_scan_stack *h
 	if (headerlen > 0) {									\
 		if (headerlen >= (s->outend - s->outptr)) {					\
 			register char *outnew;							\
-			register int len = ((s->outend - s->outbuf)+headerlen)*2+1;		\
-			outnew = g_realloc(s->outbuf, len);					\
+			register int olen = ((s->outend - s->outbuf) + headerlen) * 2 + 1;	\
+			outnew = g_realloc(s->outbuf, olen);					\
 			s->outptr = s->outptr - s->outbuf + outnew;				\
 			s->outbuf = outnew;							\
-			s->outend = outnew + len;						\
+			s->outend = outnew + olen;						\
 		}										\
 		if (start[headerlen-1] == '\r')							\
 			headerlen--;								\
@@ -1628,9 +1624,9 @@ tail_recurse:
 /*					camel_header_raw_replace(&h->headers, "Content-Type", "text/plain", offset);*/
 					/*g_warning("Multipart with no boundary, treating as text/plain");*/
 				}
-			} else if (!strcasecmp(ct->type, "message")) {
-				if (!strcasecmp(ct->subtype, "rfc822")
-				    || !strcasecmp(ct->subtype, "news")
+			} else if (!g_ascii_strcasecmp(ct->type, "message")) {
+				if (!g_ascii_strcasecmp(ct->subtype, "rfc822")
+				    || !g_ascii_strcasecmp(ct->subtype, "news")
 				    /*|| !g_ascii_strcasecmp(ct->subtype, "partial")*/) {
 					type = CAMEL_MIME_PARSER_STATE_MESSAGE;
 				}
@@ -1764,7 +1760,7 @@ tail_recurse:
 		return;
 
 	default:
-		g_warning("Invalid state in camel-mime-parser: %d", s->state);
+		g_warning ("Invalid state in camel-mime-parser: %u", s->state);
 		break;
 	}
 
@@ -1833,7 +1829,7 @@ int main(int argc, char **argv)
 		name = argv[i];
 		printf("opening: %s", name);
 		
-		fd = open(name, O_RDONLY);
+		fd = g_open(name, O_RDONLY|O_BINARY, 0);
 		if (fd==-1) {
 			perror("Cannot open mailbox");
 			exit(1);
@@ -1866,7 +1862,7 @@ int main(int argc, char **argv)
 
 				encoding = camel_header_raw_find(&s->parts->headers, "Content-transfer-encoding", 0);
 				printf("encoding = '%s'\n", encoding);
-				if (encoding && !strncasecmp(encoding, " base64", 7)) {
+				if (encoding && !g_ascii_strncasecmp(encoding, " base64", 7)) {
 					printf("adding base64 filter\n");
 					attachname = g_strdup_printf("attach.%d.%d", i, attach++);
 #if 0
@@ -1877,7 +1873,7 @@ int main(int argc, char **argv)
 					folder_push_filter_mime(s, 0);
 #endif
 				}
-				if (encoding && !strncasecmp(encoding, " quoted-printable", 17)) {
+				if (encoding && !g_ascii_strncasecmp(encoding, " quoted-printable", 17)) {
 					printf("adding quoted-printable filter\n");
 					attachname = g_strdup_printf("attach.%d.%d", i, attach++);
 #if 0
@@ -1895,14 +1891,14 @@ int main(int argc, char **argv)
 				break;
 			case CAMEL_MIME_PARSER_STATE_BODY_END:
 				printf("end body %d '%.*s'\n",  len, len, data);
-				if (encoding && !strncasecmp(encoding, " base64", 7)) {
+				if (encoding && !g_ascii_strncasecmp(encoding, " base64", 7)) {
 					printf("removing filters\n");
 #if 0
 					folder_filter_pull(s);
 					folder_filter_pull(s);
 #endif
 				}
-				if (encoding && !strncasecmp(encoding, " quoted-printable", 17)) {
+				if (encoding && !g_ascii_strncasecmp(encoding, " quoted-printable", 17)) {
 					printf("removing filters\n");
 #if 0
 					folder_filter_pull(s);
