@@ -1,23 +1,22 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
+/*  Camel
+ *  Copyright (C) 1999-2007 Novell, Inc. (www.novell.com)
+ *
  *  Authors: Jeffrey Stedfast <fejj@novell.com>
  *
- *  Copyright 2005 Novell, Inc. (www.novell.com)
- *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -25,21 +24,21 @@
 #include <config.h>
 #endif
 
-#include <string.h>
 #include <ctype.h>
 #include <errno.h>
+#include <string.h>
 
-#include <camel/camel-sasl.h>
-#include <camel/camel-stream-buffer.h>
-#include <camel/camel-i18n.h>
+#include <glib/gi18n-lib.h>
+
+#include "camel-sasl.h"
+#include "camel-stream-buffer.h"
 
-#include "camel-imap4-summary.h"
 #include "camel-imap4-command.h"
-#include "camel-imap4-stream.h"
-#include "camel-imap4-folder.h"
-#include "camel-imap4-utils.h"
-
 #include "camel-imap4-engine.h"
+#include "camel-imap4-folder.h"
+#include "camel-imap4-stream.h"
+#include "camel-imap4-summary.h"
+#include "camel-imap4-utils.h"
 
 #define d(x) x
 
@@ -498,7 +497,7 @@ parse_xgwextensions (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guint32 in
 	}
 	
 	if (token->token != '\n') {
-		d(fprintf (stderr, "expected ')' to close untagged FETCH response\n"));
+		d(fprintf (stderr, "expected '\\n' at the end of the XGWEXTENSIONS response\n"));
 		goto unexpected;
 	}
 	
@@ -758,8 +757,7 @@ engine_parse_namespace (CamelIMAP4Engine *engine, CamelException *ex)
 }
 
 
-/**
- * 
+/*
  * resp-text-code  = "ALERT" /
  *                   "BADCHARSET" [SP "(" astring *(SP astring) ")" ] /
  *                   capability-data / "PARSE" /
@@ -768,7 +766,7 @@ engine_parse_namespace (CamelIMAP4Engine *engine, CamelException *ex)
  *                   "UIDNEXT" SP nz-number / "UIDVALIDITY" SP nz-number /
  *                   "UNSEEN" SP nz-number /
  *                   atom [SP 1*<any TEXT-CHAR except "]">]
- **/
+ */
 
 static struct {
 	const char *name;
@@ -981,7 +979,7 @@ camel_imap4_engine_parse_resp_code (CamelIMAP4Engine *engine, CamelException *ex
 		
 		if (resp != NULL) {
 			if (token.token == CAMEL_IMAP4_TOKEN_NUMBER)
-				resp->v.copyuid.srcset = g_strdup_printf ("%u", token.v.number);
+				resp->v.copyuid.srcset = g_strdup_printf ("%lu", token.v.number);
 			else
 				resp->v.copyuid.srcset = g_strdup (token.v.atom);
 		}
@@ -997,7 +995,7 @@ camel_imap4_engine_parse_resp_code (CamelIMAP4Engine *engine, CamelException *ex
 		
 		if (resp != NULL) {
 			if (token.token == CAMEL_IMAP4_TOKEN_NUMBER)
-				resp->v.copyuid.destset = g_strdup_printf ("%u", token.v.number);
+				resp->v.copyuid.destset = g_strdup_printf ("%lu", token.v.number);
 			else
 				resp->v.copyuid.destset = g_strdup (token.v.atom);
 		}
@@ -1206,7 +1204,7 @@ camel_imap4_engine_handle_untagged_1 (CamelIMAP4Engine *engine, camel_imap4_toke
 			if (untagged (engine, ic, v, token, ex) == -1)
 				return -1;
 		} else {
-			d(fprintf (stderr, "Unrecognized untagged response: * %u %s\n", v, token->v.atom));
+			d(fprintf (stderr, "Unrecognized untagged response: * %lu %s\n", v, token->v.atom));
 		}
 		
 		/* find the eoln token */
