@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Hans Petter Jansson <hpj@novell.com>
  */
@@ -36,9 +36,9 @@
 #include <libedataserverui/e-destination-store.h>
 #include <libedataserverui/e-contact-store.h>
 #include <libedataserverui/e-book-auth-util.h>
-#include <libedataserver/e-sexp.h>
-#include <libedataserver/e-categories.h>
-#include <libedataserver/libedataserver-private.h>
+#include "libedataserver/e-sexp.h"
+#include "libedataserver/e-categories.h"
+#include "libedataserver/libedataserver-private.h"
 #include "e-name-selector-dialog.h"
 
 typedef struct {
